RbConfig

Struct RbConfig 

pub struct RbConfig {
    pub search_paths: Vec<SearchPath>,
    pub libs: Vec<Library>,
    pub link_args: Vec<String>,
    pub cflags: Vec<String>,
    pub blocklist_lib: Vec<String>,
    pub blocklist_link_arg: Vec<String>,
    /* private fields */
}
Extracts structured information from raw compiler/linker flags to make compiling Ruby gems easier.

Fields

search_paths: Vec<SearchPath>libs: Vec<Library>link_args: Vec<String>cflags: Vec<String>blocklist_lib: Vec<String>blocklist_link_arg: Vec<String>

Implementations

Source

impl RbConfig

pub fn all_keys(&self) -> Keys<'_, String, String>

All keys in the RbConfig’s value map.

pub fn current() -> RbConfig

Instantiates a new RbConfig for the current Ruby.

Pushes the LIBRUBYARG flags so Ruby will be linked.

pub fn libruby_static_name(&self) -> String

Get the name for libruby-static (i.e. ruby.3.1-static).

pub fn libruby_so_name(&self) -> String

Get the name for libruby (i.e. ruby.3.1)

pub fn platform(&self) -> String

Get the platform for the current ruby.

pub fn blocklist_lib(&mut self, name: &str) -> &mut RbConfig

Filter the libs, removing the ones that are not needed.

Blocklist a link argument.

pub fn ruby_version_slug(&self) -> String

Returns the current ruby program version.

pub fn cppflags(&self) -> Vec<String>

Get the CPPFLAGS from the RbConfig, making sure to subsitute variables.

pub fn is_cross_compiling(&self) -> bool

Returns true if the current Ruby is cross compiling.

pub fn validate_cargo_target(&self) -> Result<(), String>

Checks that Ruby’s C headers use the same operating-system ABI as Cargo’s target.

Bindgen can locate headers from a cross-compilation sysroot, but headers from a Ruby built for a different target are not compatible. In particular, RubyInstaller uses MinGW headers which cannot be used with Rust’s MSVC target.

pub fn get(&self, key: &str) -> Option<String>

Returns the value of the given key from the either the matching RBCONFIG_{key} environment variable or RbConfig::CONFIG[{key}] hash.

pub fn use_rpath(&mut self) -> &mut RbConfig

Enables the use of rpath for linking.

pub fn push_cflags(&mut self, cflags: &str) -> &mut Self

Push cflags string

pub fn major_minor(&self) -> Option<(u32, u32)>

Get major/minor version tuple of Ruby

pub fn cargo_args(&self) -> Vec<String>

Get the rb_config output for cargo

pub fn print_cargo_args(&self)

Print to rb_config output for cargo

pub fn push_dldflags(&mut self, input: &str) -> &mut Self

Adds items to the rb_config based on a string from LDFLAGS/DLDFLAGS

pub fn set_value_for_key(&mut self, key: &str, value: String)

Sets a value for a key

pub fn has_ruby_dln_check_abi(&self) -> bool

pub fn ruby_engine(&self) -> RubyEngine

The RUBY_ENGINE we are building for

pub fn have_ruby_header<T: AsRef<str>>(&self, header: T) -> bool